@@ -349,19 +349,20 @@ gpm_applet_destroy_popup_cb (GpmBrightnessApplet *applet)
 static void
 gpm_applet_update_tooltip (GpmBrightnessApplet *applet)
 {
-	static gchar buf[101];
+	gchar *buf = NULL;
 	if (applet->popped == FALSE) {
 		if (applet->proxy == NULL) {
-			snprintf (buf, 100, _("Cannot connect to gnome-power-manager"));
+			buf = g_strdup (_("Cannot connect to gnome-power-manager"));
 		} else if (applet->call_worked == FALSE) {
-			snprintf (buf, 100, _("Cannot get laptop panel brightness"));
+			buf = g_strdup (_("Cannot get laptop panel brightness"));
 		} else {
-			snprintf (buf, 100, _("LCD brightness : %d%%"), applet->level);
+			buf = g_strdup_printf (_("LCD brightness : %d%%"), applet->level);
 		}
 		gtk_widget_set_tooltip_text (GTK_WIDGET(applet), buf);
 	} else {
 		gtk_widget_set_tooltip_text (GTK_WIDGET(applet), NULL);
 	}
+	g_free (buf);
 }
 
 /**
@@ -591,6 +592,7 @@ gpm_applet_create_popup (GpmBrightnessApplet *applet)
 	/* window */
 	applet->popup = gtk_window_new (GTK_WINDOW_POPUP);
 	GTK_WIDGET_UNSET_FLAGS (applet->popup, GTK_TOPLEVEL);
+	gtk_window_set_type_hint (GTK_WINDOW(applet->popup), GDK_WINDOW_TYPE_HINT_UTILITY);
 	gtk_widget_set_parent (applet->popup, GTK_WIDGET(applet));
 	gtk_container_add (GTK_CONTAINER(applet->popup), frame);
 }
@@ -805,7 +807,7 @@ gpm_applet_help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname
 						GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_MESSAGE_ERROR,
 						GTK_BUTTONS_CLOSE,
-						error->message);
+						"%s", error->message);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		g_error_free (error);
