@@ -331,8 +331,8 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("percentage");
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Accuracy of reading"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("Valid data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_BLUE, _("No data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Valid data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
@@ -348,9 +348,9 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("time");
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Average time elapsed"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Valid data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("No data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_GREY, _("Extrapolated data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Valid data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("Extrapolated data"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
@@ -366,7 +366,7 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("percentage");
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Accuracy of reading"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Valid data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Valid data"));
 		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
@@ -383,9 +383,9 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("time");
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Average time elapsed"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Valid data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("No data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_GREY, _("Extrapolated data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Valid data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("Extrapolated data"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
@@ -645,22 +645,18 @@ gpm_info_log_do_poll (gpointer data)
 			colour = GPM_COLOUR_CHARGED;
 		}
 
-		gpm_array_add (info->priv->percentage_data, value_x,
-			       unit->percentage, colour);
-
-		/* sanity check to less than 100W */
-		if (unit->rate < 100000) {
+		if (unit->percentage > 0) {
+			gpm_array_add (info->priv->percentage_data, value_x,
+				       unit->percentage, colour);
+		}
+		if (unit->rate > 0) {
 			gpm_array_add (info->priv->rate_data, value_x,
 				       unit->rate, colour);
 		}
-
-		/* sanity check to less than 10 hours */
-		if (unit->time_discharge < 10*60*60) {
-			gpm_array_add (info->priv->time_data, value_x,
-					   unit->time_discharge, colour);
+		if (unit->voltage > 0) {
+			gpm_array_add (info->priv->voltage_data, value_x,
+				       unit->voltage, colour);
 		}
-		gpm_array_add (info->priv->voltage_data, value_x,
-			       unit->voltage, colour);
 	}
 	return TRUE;
 }
