@@ -48,7 +48,6 @@
 #include "gpm-conf.h"
 #include "gpm-control.h"
 #include "gpm-common.h"
-#include "gpm-cpufreq.h"
 #include "gpm-debug.h"
 #include "gpm-dpms.h"
 #include "gpm-idle.h"
@@ -100,7 +99,6 @@ struct GpmManagerPrivate
 	/* interactive services */
 	GpmBacklight		*backlight;
 	GpmSrvBrightnessKbd	*srv_brightness_kbd;
-	GpmCpufreq	 	*cpufreq;
 	GpmSrvScreensaver 	*srv_screensaver;
 };
 
@@ -171,7 +169,7 @@ gpm_manager_is_inhibit_valid (GpmManager *manager,
 			      const char *action)
 {
 	gboolean has_inhibit;
-	gchar *title;
+	gchar *title = NULL;
 
 	/* We have to decide on whether this is a idle action or a user keypress */
 	gpm_inhibit_has_inhibit (manager->priv->inhibit, &has_inhibit, NULL);
@@ -182,22 +180,22 @@ gpm_manager_is_inhibit_valid (GpmManager *manager,
 
 		/*Compose message for each possible action*/
 		if (strcmp (action, "suspend") == 0) {
-				title = g_strdup_printf (_("Request to suspend")); 
+				title = g_strdup (_("Request to suspend")); 
 
 		} else if (strcmp (action, "hibernate") == 0) {
-				title = g_strdup_printf (_("Request to hibernate")); 
+				title = g_strdup (_("Request to hibernate")); 
 
 		} else if (strcmp (action, "policy action") == 0) {
-				title = g_strdup_printf (_("Request to do policy action")); 
+				title = g_strdup (_("Request to do policy action")); 
 
 		} else if (strcmp (action, "reboot") == 0) {
-				title = g_strdup_printf (_("Request to reboot")); 
+				title = g_strdup (_("Request to reboot")); 
 
 		} else if (strcmp (action, "shutdown") == 0) {
-				title = g_strdup_printf (_("Request to shutdown")); 
+				title = g_strdup (_("Request to shutdown")); 
 
 		} else if (strcmp (action, "timeout action") == 0) {
-				title = g_strdup_printf (_("Request to do timeout action"));
+				title = g_strdup (_("Request to do timeout action"));
 		}
 		
 		gpm_inhibit_get_message (manager->priv->inhibit, message, action);
@@ -325,17 +323,6 @@ gpm_manager_action_suspend (GpmManager *manager, const gchar *reason)
 	gboolean allowed;
 	GError *error = NULL;
 
-	if (gpm_control_is_policy_timout_valid (manager->priv->control) == FALSE) {
-		/* error msg timeout not valid */
-		gpm_notify_display (manager->priv->notify,
-				    _("Action forbidden"),
-				    _("Policy timeout is not valid. Please wait a few seconds and try again."),
-				    GPM_NOTIFY_TIMEOUT_SHORT,
-				    GPM_STOCK_APP_ICON,
-				    GPM_NOTIFY_URGENCY_NORMAL);
-		return FALSE;
-	}
-
 	/* check if the admin has disabled */
 	gpm_conf_get_bool (manager->priv->conf, GPM_CONF_CAN_SUSPEND, &allowed);
 	if (allowed == FALSE) {
@@ -385,17 +372,6 @@ gpm_manager_action_hibernate (GpmManager *manager, const gchar *reason)
 	gboolean allowed;
 	GError *error = NULL;
 
-	if (gpm_control_is_policy_timout_valid (manager->priv->control) == FALSE) {
-		/* error msg timeout not valid */
-		gpm_notify_display (manager->priv->notify,
-				    _("Action forbidden"),
-				    _("Policy timeout is not valid. Please wait a few seconds and try again."),
-				    GPM_NOTIFY_TIMEOUT_SHORT,
-				    GPM_STOCK_APP_ICON,
-				    GPM_NOTIFY_URGENCY_NORMAL);
-		return FALSE;
-	}
-
 	/* check if the admin has disabled */
 	gpm_conf_get_bool (manager->priv->conf, GPM_CONF_CAN_HIBERNATE, &allowed);
 	if (allowed == FALSE) {
@@ -1491,7 +1467,7 @@ gpm_engine_charge_critical_cb (GpmEngine      *engine,
 
 		/* use different text for different actions */
 		if (strcmp (action, ACTION_NOTHING) == 0) {
-			action_text = g_strdup_printf (_("Plug in your AC adapter to avoid losing data."));
+			action_text = g_strdup (_("Plug in your AC adapter to avoid losing data."));
 
 		} else if (strcmp (action, ACTION_SUSPEND) == 0) {
 			action_text = g_strdup_printf (_("This computer will suspend in %s if the AC is not connected."), time_text);
@@ -1603,17 +1579,17 @@ gpm_engine_charge_action_cb (GpmEngine      *engine,
 
 		/* use different text for different actions */
 		if (strcmp (action, ACTION_NOTHING) == 0) {
-			message = _("The UPS is below the critical level and "
-				    "this computer will <b>power-off</b> when the "
-				    "UPS becomes completely empty.");
+			message = g_strdup (_("The UPS is below the critical level and "
+				              "this computer will <b>power-off</b> when the "
+				              "UPS becomes completely empty."));
 
 		} else if (strcmp (action, ACTION_HIBERNATE) == 0) {
-			message = _("The UPS is below the critical level and "
-				    "this computer is about to hibernate.");
+			message = g_strdup (_("The UPS is below the critical level and "
+				              "this computer is about to hibernate."));
 
 		} else if (strcmp (action, ACTION_SHUTDOWN) == 0) {
-			message = _("The UPS is below the critical level and "
-				    "this computer is about to shutdown.");
+			message = g_strdup (_("The UPS is below the critical level and "
+				              "this computer is about to shutdown."));
 		}
 
 		g_free (action);
@@ -1747,9 +1723,6 @@ gpm_manager_init (GpmManager *manager)
 	manager->priv->hal_power = hal_gpower_new ();
 	manager->priv->sound = gpm_sound_new ();
 
-	/* try and start an interactive service */
-	manager->priv->cpufreq = gpm_cpufreq_new ();
-
 	/* try and start an interactive service */
 	manager->priv->screensaver = gpm_screensaver_new ();
 	g_signal_connect (manager->priv->screensaver, "auth-request",
@@ -1881,9 +1854,6 @@ gpm_manager_finalize (GObject *object)
 	if (manager->priv->button) {
 		g_object_unref (manager->priv->button);
 	}
-	if (manager->priv->cpufreq) {
-		g_object_unref (manager->priv->cpufreq);
-	}
 	if (manager->priv->backlight) {
 		g_object_unref (manager->priv->backlight);
 	}
